import {
  select,
  json,
  tree,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';

// Extract Width and Height from the Body
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const margin = { top: 10, right: 50, bottom: 10, left: 70 };
const innerWidth = width-margin.left-margin.right;
const innerHeight= height-margin.top-margin.bottom;

// Init Tree Layout
const treeLayout = tree()
	.size([innerHeight,innerWidth]);

// Generate Path function
const linkPath = linkHorizontal()
  .x(d =>d.y)
  .y(d =>d.x);

// Select the SVG and set Width and Height
const svg = select('svg')
	.attr('width', width)
  .attr('height',height);
// Create a group that contains the vizualization

const zoomG = svg.append('g');
const g = zoomG.append('g')
		.attr('transform',`translate(${margin.left},${margin.top})`);

// Add zoom to the SVG
svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));


// Load the data file
json('data.json')
	.then(data => {
  	// Get the Top Parent(root) item
  	const root = hierarchy(data);
  	// Create Tree link structure
  	const links = treeLayout(root).links();
  	// Append the paths to the group
  	g.selectAll('path').data(links)
  		.enter().append('path')
  			.attr('d', linkPath);

  	// Append the nodes to the group
  	const node = g.selectAll('.node')
    	.data(root.descendants())
    	.enter().append('g')
    		.attr('class', 'node')
    		.attr('transform', d => `translate(${d.y}, ${d.x})`);
  
  	// node.append('circle')
  	// 	.attr('r',2.5);
  	node.append('text')
  		.attr('dy', '0.32em')
  		.attr('text-anchor',d => d.children ? 'middle' : 'start')
  		.attr('font-size', d => 3.2-d.depth + 'em')
   		.text(d => d.data.data.id)
  		

});